@@ -327,7 +327,7 @@ bool document::set_info_key(const std::string &key, const ustring &val)
 }
 
 /**
- Gets the time_t value of the specified \p key of the document
+ Gets the time_type value of the specified \p key of the document
  information.
 
  \returns the time_t value for the \p key
@@ -344,6 +344,27 @@ time_type document::info_date(const std::string &key) const
         return time_type(-1);
     }
 
+    return static_cast<time_type>(dateStringToTime(goo_date.get()));
+}
+
+/**
+ Gets the time_t value of the specified \p key of the document
+ information.
+
+ \returns the time_t value for the \p key
+ \see info_keys, info_date
+ */
+time_t document::info_date_t(const std::string &key) const
+{
+    if (d->is_locked) {
+        return time_t(-1);
+    }
+
+    std::unique_ptr<GooString> goo_date(d->doc->getDocInfoStringEntry(key.c_str()));
+    if (!goo_date.get()) {
+        return time_t(-1);
+    }
+
     return dateStringToTime(goo_date.get());
 }
 
@@ -373,6 +394,31 @@ bool document::set_info_date(const std::string &key, time_type val)
     return true;
 }
 
+/**
+ Sets the time_t value of the specified \p key of the %document information
+ to \p val.
+ If \p val == time_t(-1), the entry specified by \p key is removed.
+
+ \returns true on success, false on failure
+ */
+bool document::set_info_date_t(const std::string &key, time_t val)
+{
+    if (d->is_locked) {
+        return false;
+    }
+
+    GooString *goo_date;
+
+    if (val == time_t(-1)) {
+        goo_date = nullptr;
+    } else {
+        goo_date = timeToDateString(&val);
+    }
+
+    d->doc->setDocInfoStringEntry(key.c_str(), goo_date);
+    return true;
+}
+
 /**
  Gets the %document's title.
 
@@ -654,6 +700,26 @@ time_type document::get_creation_date() const
         return time_type(-1);
     }
 
+    return static_cast<time_type>(dateStringToTime(goo_creation_date.get()));
+}
+
+/**
+ Gets the document's creation date as a time_t value.
+
+ \returns the document's creation date as a time_t value
+ \see set_creation_date, info_date
+ */
+time_t document::get_creation_date_t() const
+{
+    if (d->is_locked) {
+        return time_t(-1);
+    }
+
+    std::unique_ptr<GooString> goo_creation_date(d->doc->getDocInfoCreatDate());
+    if (!goo_creation_date.get()) {
+        return time_t(-1);
+    }
+
     return dateStringToTime(goo_creation_date.get());
 }
 
@@ -682,6 +748,30 @@ bool document::set_creation_date(time_type creation_date)
     return true;
 }
 
+/**
+ Sets the %document's creation date to \p creation_date.
+ If \p creation_date == time_t(-1), the %document's creation date is removed.
+
+ \returns true on success, false on failure
+ */
+bool document::set_creation_date_t(time_t creation_date)
+{
+    if (d->is_locked) {
+        return false;
+    }
+
+    GooString *goo_creation_date;
+
+    if (creation_date == time_t(-1)) {
+        goo_creation_date = nullptr;
+    } else {
+        goo_creation_date = timeToDateString(&creation_date);
+    }
+
+    d->doc->setDocInfoCreatDate(goo_creation_date);
+    return true;
+}
+
 /**
  Gets the document's modification date as a time_type value.
 
@@ -699,6 +789,26 @@ time_type document::get_modification_date() const
         return time_type(-1);
     }
 
+    return static_cast<time_type>(dateStringToTime(goo_modification_date.get()));
+}
+
+/**
+ Gets the document's modification date as a time_t value.
+
+ \returns the document's modification date as a time_t value
+ \see set_modification_date, info_date
+ */
+time_t document::get_modification_date_t() const
+{
+    if (d->is_locked) {
+        return time_t(-1);
+    }
+
+    std::unique_ptr<GooString> goo_modification_date(d->doc->getDocInfoModDate());
+    if (!goo_modification_date.get()) {
+        return time_t(-1);
+    }
+
     return dateStringToTime(goo_modification_date.get());
 }
 
@@ -727,6 +837,30 @@ bool document::set_modification_date(time_type mod_date)
     return true;
 }
 
+/**
+ Sets the %document's modification date to \p mod_date.
+ If \p mod_date == time_t(-1), the %document's modification date is removed.
+
+ \returns true on success, false on failure
+ */
+bool document::set_modification_date_t(time_t mod_date)
+{
+    if (d->is_locked) {
+        return false;
+    }
+
+    GooString *goo_mod_date;
+
+    if (mod_date == time_t(-1)) {
+        goo_mod_date = nullptr;
+    } else {
+        goo_mod_date = timeToDateString(&mod_date);
+    }
+
+    d->doc->setDocInfoModDate(goo_mod_date);
+    return true;
+}
+
 /**
  Removes the %document's Info dictionary.
 
