@@ -41,7 +41,8 @@
 #include "PDFDocFactory.h"
 #include "Error.h"
 #include "GlobalParams.h"
-#include "SignatureHandler.h"
+#include "NSSCryptoSignBackend.h"
+#include "CryptoSignBackend.h"
 #include "SignatureInfo.h"
 #include "Win32Console.h"
 #include "numberofcharacters.h"
@@ -200,9 +201,15 @@ static std::vector<std::unique_ptr<X509CertificateInfo>> getAvailableSigningCert
             return nullptr;
         }
     };
-    SignatureHandler::setNSSPasswordCallback(passwordCallback);
-    std::vector<std::unique_ptr<X509CertificateInfo>> vCerts = SignatureHandler::getAvailableSigningCertificates();
-    SignatureHandler::setNSSPasswordCallback({});
+    NSSSignatureConfiguration::setNSSPasswordCallback(passwordCallback);
+    auto backend = CryptoSign::Factory::createActive();
+    if (!backend) {
+        *error = true;
+        printf("No backends for cryptographic signatures available");
+        return {};
+    }
+    std::vector<std::unique_ptr<X509CertificateInfo>> vCerts = backend->getAvailableSigningCertificates();
+    NSSSignatureConfiguration::setNSSPasswordCallback({});
     if (passwordNeeded) {
         *error = true;
         printf("Password is needed to access the NSS database.\n");
@@ -262,7 +269,7 @@ int main(int argc, char *argv[])
         return 0;
     }
 
-    SignatureHandler::setNSSDir(nssDir);
+    NSSSignatureConfiguration::setNSSDir(nssDir);
 
     if (listNicknames) {
         bool getCertsError;
